Osvědčení | OiRA
Description: V závislosti na přístupu národního partnera/vývojáře nástroje OiRA můžete pro své hodnocení rizik případně získat osvědčení. Pro bližší informace o výhodách těchto osvědčení se obraťte na příslušného národního partnera OiRA.

Témata

# Osvědčení

V závislosti na přístupu národního partnera/vývojáře nástroje OiRA můžete pro své hodnocení rizik případně získat osvědčení. Pro bližší informace o výhodách těchto osvědčení se obraťte na příslušného národního partnera OiRA.

Jak získat osvědčení

## Provést úplné hodnocení rizik

Během vaší činnosti při hodnocení rizik bude nástroj OiRA zaznamenávat váš pokrok. Po posouzení určitého počtu rizik vás nástroj informuje o možnosti získat po dokončení úplného hodnocení rizik osvědčení. Každý národní partner/vývojář nástroje OiRA stanoví prahovou hodnotu (procenta) pro definici „úplného“ hodnocení rizik. Osvědčení je dostupné pomocí tlačítka „Stav“ v nabídce vlevo na obrazovce.

Stavová stránka zobrazuje, že je k dispozici osvědčení.

## Zobrazit a zveřejnit osvědčení

Kliknete-li na tlačítko „Zobrazit osvědčení“, budete vyzváni, abyste zadali název společnosti, která by měla být v osvědčení uvedena. Podle vnitrostátního nastavení můžete být požádáni o zadání dalších údajů, aby bylo zajištěno, že osvědčení obsahuje veškeré údaje, které potřebujete poskytnout.

Zadat všechny údaje potřebné pro osvědčení.

Zaškrtnete-li políčko s označením „Zveřejnit“, objeví se jedinečný odkaz (URL) na vaše osvědčení. Tento odkaz zkopírujte a sdělte příslušným osobám jako doklad o tom, že jste provedli hodnocení rizik.

Poznámka: Zveřejněny budou pouze údaje uvedené na této stránce. V nabídce na internetových stránkách OiRA není tento odkaz k dispozici - týká se pouze vás. Teoreticky však osvědčení, které jste vytvořili, vidí každý, kdo si prohlíží internet!

Osvědčení ukazuje pouze to, že jste se v nástroji pro hodnocení rizik zabývali určitým počtem rizik, žádné další informace však uvedeny nejsou. Konkrétní odpovědi v rámci hodnocení rizik poskytnuté při vyplňování nástroje OiRA si můžete prohlédnout pouze vy a nikdo jiný.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More